pub struct RemoteCatalogProvider { /* private fields */ }Expand description
Provider serving a catalog sourced from a remote inspection report and dispatching calls through the service’s REST action path.
Implementations
Sourceimpl RemoteCatalogProvider
impl RemoteCatalogProvider
Sourcepub fn new(service: SomaService, catalog: ProviderCatalog) -> Self
pub fn new(service: SomaService, catalog: ProviderCatalog) -> Self
Builds the provider over the given service and remote catalog.